@@ -19,7 +19,7 @@ SEXP toTPCmsm(
 	h = VECTOR_ELT(lst, 1);
 	register int i, j, k;
 	register int64_t y;
-	const int nt = GET_LENGTH(UT), nx = GET_LENGTH(UX);
+	Cint nt = GET_LENGTH(UT), nx = GET_LENGTH(UX);
 	const int64_t ntx = nt*nx;
 	SEXP aest;
 	PROTECT( aest = alloc3DArray(REALSXP, nt, nx, 5) );
@@ -40,32 +40,32 @@ SEXP toTPCmsm(
 	const char *name1 = CHAR( STRING_ELT(statenames, 0) );
 	const char *name2 = CHAR( STRING_ELT(statenames, 1) );
 	const char *name3 = CHAR( STRING_ELT(statenames, 2) );
-	i = strlen(name1), j = strlen(name2), k = strlen(name3);
-	char *name11 = (char*)malloc( (i+i+2)*sizeof(char) );
+	size_t u = strlen(name1), v = strlen(name2), w = strlen(name3);
+	char *name11 = (char*)malloc( (u+u+2)*sizeof(char) );
 	if (name11 == NULL) error("toTPCmsm: No more memory\n");
 	strcpy(name11, name1);
-	strcpy(&name11[i], " ");
-	strcpy(&name11[i+1], name1);
-	char *name12 = (char*)malloc( (i+j+2)*sizeof(char) );
+	strcpy(&name11[u], " ");
+	strcpy(&name11[u+1], name1);
+	char *name12 = (char*)malloc( (u+v+2)*sizeof(char) );
 	if (name12 == NULL) error("toTPCmsm: No more memory\n");
 	strcpy(name12, name1);
-	strcpy(&name12[i], " ");
-	strcpy(&name12[i+1], name2);
-	char *name13 = (char*)malloc( (i+k+2)*sizeof(char) );
+	strcpy(&name12[u], " ");
+	strcpy(&name12[u+1], name2);
+	char *name13 = (char*)malloc( (u+w+2)*sizeof(char) );
 	if (name13 == NULL) error("toTPCmsm: No more memory\n");
 	strcpy(name13, name1);
-	strcpy(&name13[i], " ");
-	strcpy(&name13[i+1], name3);
-	char *name22 = (char*)malloc( (j+j+2)*sizeof(char) );
+	strcpy(&name13[u], " ");
+	strcpy(&name13[u+1], name3);
+	char *name22 = (char*)malloc( (v+v+2)*sizeof(char) );
 	if (name22 == NULL) error("toTPCmsm: No more memory\n");
 	strcpy(name22, name2);
-	strcpy(&name22[j], " ");
-	strcpy(&name22[j+1], name2);
-	char *name23 = (char*)malloc( (j+k+2)*sizeof(char) );
+	strcpy(&name22[v], " ");
+	strcpy(&name22[v+1], name2);
+	char *name23 = (char*)malloc( (v+w+2)*sizeof(char) );
 	if (name23 == NULL) error("toTPCmsm: No more memory\n");
 	strcpy(name23, name2);
-	strcpy(&name23[j], " ");
-	strcpy(&name23[j+1], name3);
+	strcpy(&name23[v], " ");
+	strcpy(&name23[v+1], name3);
 	SEXP facenames;
 	PROTECT( facenames = NEW_CHARACTER(5) );
 	SET_STRING_ELT( facenames, 0, mkChar(name11) );
