@@ -7,7 +7,7 @@
 #include "RngArray.h"
 #include "rthreads.h"
 
-void attribute_visible R_unload_TPmsm(DllInfo *info) {
+void attribute_visible R_unload_TPmsm(void) {
 	RngArray_DeleteStream(&global_num_procs, RngArray);
 	free(RngArray);
 	return;
